pub struct EncodingPreservation { /* private fields */ }Expand description
Controls whether a Coercion preserves an argument’s physical encoding
(e.g. dictionary) instead of materializing it to the coerced value type.
Implementations
Sourceimpl EncodingPreservation
impl EncodingPreservation
Sourcepub const fn dictionary() -> Self
pub const fn dictionary() -> Self
Preserve dictionary encoding and coerce only the dictionary values.
Sourcepub const fn with_dictionary(self) -> Self
pub const fn with_dictionary(self) -> Self
Preserve dictionary encoding and coerce only the dictionary values.
Sourcepub const fn preserve_dictionary(self) -> bool
pub const fn preserve_dictionary(self) -> bool
Returns whether dictionary encoding should be preserved.