SortProperties

Enum SortProperties 

pub enum SortProperties {
    Ordered(SortOptions),
    Unordered,
    Singleton,
}
To propagate SortOptions across the PhysicalExpr, it is insufficient to simply use Option<SortOptions>: There must be a differentiation between unordered columns and literal values, since literals may not break the ordering when they are used as a child of some binary expression when the other child has some ordering. On the other hand, unordered columns cannot maintain ordering when they take part in such operations.

Example: ((a_ordered + b_unordered) + c_ordered) expression cannot end up with sorted data; however the ((a_ordered + 999) + c_ordered) expression can. Therefore, we need two different variants for literals and unordered columns as literals are often more ordering-friendly under most mathematical operations.

Variants



Ordered(SortOptions)

Use the ordinary SortOptions struct to represent ordered data:



Unordered



Singleton

Implementations

Source

impl SortProperties

pub fn add(&self, rhs: &Self) -> Self

pub fn sub(&self, rhs: &Self) -> Self

pub fn gt_or_gteq(&self, rhs: &Self) -> Self

pub fn and_or(&self, rhs: &Self) -> Self