Probabilistic distributions for expression-level statistics (unused).
Note: All public items in this module are deprecated as of 54.0.0.
See https://github.com/apache/datafusion/pull/22071 for details.
Structs
- Bernoulli
Distribution Deprecated - Bernoulli distribution with success probability
p. Ifphas a null value, the success probability is unknown. For a more in-depth discussion, see: - Exponential
Distribution Deprecated - Exponential distribution with an optional shift. The probability density function (PDF) is defined as follows:
- Gaussian
Distribution Deprecated - Gaussian (normal) distribution, represented by its mean and variance. For a more in-depth discussion, see:
- Generic
Distribution Deprecated - A generic distribution whose functional form is not available, which is approximated via some summary statistics. For a more in-depth discussion, see:
- Uniform
Distribution Deprecated - Uniform distribution, represented by its range. If the given range extends towards infinity, the distribution will be improper – which is OK. For a more in-depth discussion, see:
Enums
- Distribution
Deprecated - This object defines probabilistic distributions that encode uncertain information about a single, scalar value. Currently, we support five core statistical distributions. New variants will be added over time.
Functions
- combine_
bernoullis Deprecated - This function takes a logical operator and two Bernoulli distributions,
and it returns a new Bernoulli distribution that represents the result of
the operation. Currently, only
ANDandORoperations are supported. - combine_
gaussians Deprecated - Applies the given operation to the given Gaussian distributions. Currently,
this function handles only addition and subtraction operations. If the
result is not a Gaussian random variable, it returns
None. For details, see: - compute_
mean Deprecated - Computes the mean value for the result of the given binary operation on
two unknown quantities represented by their
Distributionobjects. - compute_
median Deprecated - Computes the median value for the result of the given binary operation on
two unknown quantities represented by its
Distributionobjects. Currently, the median is calculable only for addition and subtraction operations on: - compute_
variance Deprecated - Computes the variance value for the result of the given binary operation on
two unknown quantities represented by their
Distributionobjects. - create_
bernoulli_ from_ comparison Deprecated - Creates a new
Bernoullidistribution by computing the resulting probability. Expectsopto be a comparison operator, withleftandrighthaving numeric distributions. The resulting distribution has theFloat64data type. - new_
generic_ from_ binary_ op Deprecated - Creates a new
Genericdistribution that represents the result of the given binary operation on two unknown quantities represented by theirDistributionobjects. The function computes the mean, median and variance if possible.