compute_variance

Function compute_variance 

pub fn compute_variance(
    op: &Operator,
    left: &Distribution,
    right: &Distribution,
) -> Result<ScalarValue>
👎Deprecated since 54.0.0:

Part of the unused Statistics V2 framework; see https://github.com/apache/datafusion/pull/22071

Computes the variance value for the result of the given binary operation on two unknown quantities represented by their Distribution objects.