new_generic_from_binary_op

Function new_generic_from_binary_op 

pub fn new_generic_from_binary_op(
    op: &Operator,
    left: &Distribution,
    right: &Distribution,
) -> Result<Distribution>
👎Deprecated since 54.0.0:

Part of the unused Statistics V2 framework; see https://github.com/apache/datafusion/pull/22071

Creates a new Generic distribution that represents the result of the given binary operation on two unknown quantities represented by their Distribution objects. The function computes the mean, median and variance if possible.